summaryrefslogtreecommitdiff
path: root/caddy/entrypoint.sh
diff options
context:
space:
mode:
Diffstat (limited to 'caddy/entrypoint.sh')
-rw-r--r--caddy/entrypoint.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/caddy/entrypoint.sh b/caddy/entrypoint.sh
index cf123ce..16edf36 100644
--- a/caddy/entrypoint.sh
+++ b/caddy/entrypoint.sh
@@ -3,9 +3,9 @@ set -e
PROXY_CONF=/tmp/proxy_forward.caddy
# Build basicauth lines from shared users.conf
AUTH_LINES=""
-if [ -f /etc/proxy/users.conf ]; then
+if [ "${PROXY_NO_AUTH:-0}" != "1" ] && [ -f /etc/proxy/users.conf ]; then
while IFS=' ' read -r user pass || [ -n "$user" ]; do
[ -z "$user" ] && continue
case "$user" in \#*) continue ;; esac
@@ -3,9 +3,9 @@ set -e
PROXY_CONF=/tmp/proxy_forward.caddy
-# Build basicauth lines from shared users.conf
+# Build basicauth lines from shared users.conf (skip if PROXY_NO_AUTH=1)
AUTH_LINES=""